=======
Credits
=======

Development Lead
----------------

* Ross Beyer <rbeyer@seti.org> (SETI / NASA Ames)

Contributors
------------

* Evan Schiewe (NASA Ames / KBR, Inc.)


Acknowledgments
---------------

Portions of this software were developed with support from the
following sources:

- NASA Science Mission Directorate (SMD) Volatiles Investigating Polar Exploration Rover (VIPER) mission.


Any opinions, findings, and conclusions or recommendations expressed in
this documentation are those of the authors and do not necessarily
reflect the views of the National Aeronautics and Space Administration.
